==> koishi-target-def-v1.1.2.zip: koishi-target-def-v1.1.2/index.ts <==
import { Adapter, Bot, Context, Filter, s } from 'koishi';
import _ from 'lodash';
import { RegisterSchema, SchemaProperty } from 'schemastery-gen';

@RegisterSchema()
export class ChannelTarget {
  @SchemaProperty({ description: 'Channel ID. ', required: true })
  channelId: string;
  @SchemaProperty({ description: 'Guild ID. ' })
  guildId: string;

  toDesc(): string | [string, string] {
    return this.guildId ? [this.channelId, this.guildId] : this.channelId;
  }

  toFilter(): Filter {
    return (s) => {
      if (this.channelId !== s.channelId) {
        return false;
      }
      if (this.guildId && this.guildId !== s.guildId) { 
        return false;
      }
      return true;
    };
  }
}

@RegisterSchema()
export class SendTarget {
  @SchemaProperty({
    description:
      'Bot identifier. eg. onebot:123456789. Will use first bot if not specified. s',
  })
  bot: string;

  @SchemaProperty({
    type: String,
    description: 'Private chat send targets. ',
    default: [],
  })
  users: string[];

  @SchemaProperty({
    type: ChannelTarget,
    description: 'Channel send targets. ',
    default: [],
  })
  channels: ChannelTarget[];

  private getBot(bots: Adapter.BotList) {
    if (this.bot) {
      return bots.get(this.bot);
    } else {
      return bots.find((bot) => !bot['parentBot']);
    }
  }

  private isOneBotBot(bot?: Bot) {
    return (
      bot &&
      (bot.platform === 'onebot' || bot['parentBot']?.platform === 'onebot')
    );
  }

  getContext(ctx: Context) {
    if (this.bot) {
      const [platform, id] = this.bot.split(':');
      ctx = ctx.platform(platform).self(id);
    }
    let filters: Filter[] = [];
    if (this.users?.length) {
      const userSet = new Set(this.users);
      filters.push((s) => s.type === 'private' && userSet.has(s.userId));
    }
    if (this.channels?.length) {
      filters = filters.concat(this.channels.map((c) => c.toFilter()));
    }
    if (filters.length) {
      ctx = ctx.intersect((s) => filters.some((f) => f(s)));
    }
    return ctx;
  }

  async send(bots: Adapter.BotList, content: string) {
    const bot = this.getBot(bots);
    if (!bot) {
      throw new Error(`bot ${this.bot} not found`);
    }
    let privateContent = content;
    let channelContent = content;
    if (this.isOneBotBot(bot)) {
      content = content.replace(/,url=base64/g, ',file=base64');
      privateContent = content.replace(/,url=http/g, ',file=http'); // private should be file
      channelContent = content.replace(/,file=http/g, ',url=http'); // channel should be url
    }
    return _.flatten(
      await Promise.all([
        ...this.users.map((userId) =>
          bot.sendPrivateMessage
            ? bot.sendPrivateMessage(userId, privateContent)
            : bot.sendMessage(`@${userId}`, privateContent),
        ),
        ...(this.channels?.length
          ? [
              bot.broadcast(
                this.channels.map((c) => c.toDesc()),
                channelContent,
              ),
            ]
          : []),
      ]),
    );
  }
}

==> koishi-target-def-v1.1.4.zip: koishi-target-def-v1.1.4/index.ts <==
import { Adapter, Bot, Context, Filter } from 'koishi';
import _ from 'lodash';
import { RegisterSchema, SchemaProperty } from 'schemastery-gen';

@RegisterSchema()
export class ChannelTarget {
  @SchemaProperty({ description: 'Channel ID. ', required: true })
  channelId: string;
  @SchemaProperty({ description: 'Guild ID. ' })
  guildId: string;

  toDesc(): string | [string, string] {
    return this.guildId ? [this.channelId, this.guildId] : this.channelId;
  }

  toFilter(): Filter {
    return (s) => {
      if (this.channelId !== s.channelId) {
        return false;
      }
      if (this.guildId && this.guildId !== s.guildId) { 
        return false;
      }
      return true;
    };
  }
}

@RegisterSchema()
export class SendTarget {
  @SchemaProperty({
    description:
      'Bot identifier. eg. onebot:123456789. Will use first bot if not specified. s',
  })
  bot: string;

  @SchemaProperty({
    type: String,
    description: 'Private chat send targets. ',
    default: [],
  })
  users: string[];

  @SchemaProperty({
    type: ChannelTarget,
    description: 'Channel send targets. ',
    default: [],
  })
  channels: ChannelTarget[];

  getBot(bots: Adapter.BotList) {
    if (this.bot) {
      return bots.get(this.bot);
    } else {
      return bots.find((bot) => !bot['parentBot']);
    }
  }

  private isOneBotBot(bot?: Bot) {
    return (
      bot &&
      (bot.platform === 'onebot' || bot['parentBot']?.platform === 'onebot')
    );
  }

  getContext(ctx: Context) {
    if (this.bot) {
      const [platform, id] = this.bot.split(':');
      ctx = ctx.platform(platform).self(id);
    }
    let filters: Filter[] = [];
    if (this.users?.length) {
      const userSet = new Set(this.users);
      filters.push((s) => s.subtype === 'private' && userSet.has(s.userId));
    }
    if (this.channels?.length) {
      filters = filters.concat(this.channels.map((c) => c.toFilter()));
    }
    if (filters.length) {
      ctx = ctx.intersect((s) => filters.some((f) => f(s)));
    }
    return ctx;
  }

  async send(bots: Adapter.BotList, content: string) {
    const bot = this.getBot(bots);
    if (!bot) {
      throw new Error(`bot ${this.bot} not found`);
    }
    let privateContent = content;
    let channelContent = content;
    if (this.isOneBotBot(bot)) {
      content = content.replace(/,url=base64/g, ',file=base64');
      privateContent = content.replace(/,url=http/g, ',file=http'); // private should be file
      channelContent = content.replace(/,file=http/g, ',url=http'); // channel should be url
    }
    return _.flatten(
      await Promise.all([
        ...this.users.map((userId) =>
          bot.sendPrivateMessage
            ? bot.sendPrivateMessage(userId, privateContent)
            : bot.sendMessage(`@${userId}`, privateContent),
        ),
        ...(this.channels?.length
          ? [
              bot.broadcast(
                this.channels.map((c) => c.toDesc()),
                channelContent,
              ),
            ]
          : []),
      ]),
    );
  }
}
